import tempfile
import pwd
import platform
import urllib2
import time
import os


def handle_normally(data):
    """Handle the command output normally (stdout) """
    print data


def run_command(command):
    """ Run the command, retrieve the output """
    result = {}

    outfile = tempfile.mktemp()
    errfile = tempfile.mktemp()

    t_start = time.time()

    result['command'] = command
    result['user'] = pwd.getpwuid(os.getuid()).pw_name
    result['hostname'] = platform.node()
    result['return_code'] = os.system("( %s ) > %s 2> %s" % (command, outfile, errfile)) >> 8
    result['start_time'] = t_start
    result['run_time'] = time.time() - t_start
    result['stdout'] = open(outfile, "r").read().strip()
    result['stderr'] = open(errfile, "r").read().strip()

    os.remove(outfile)
    os.remove(errfile)
    return result


def send_data(url, data, key):
    """ Send the data to the api """
    try:
        import json
    except:
        import simplejson as json

    json_string=json.dumps(data)
    opener = urllib2.build_opener(urllib2.HTTPHandler)
    request = urllib2.Request(url, data=json_string)
    request.add_header('X-AppKey', key)
    request.add_header('Content-Type', 'application/json')
    request.get_method = lambda: 'POST'

    try:
        response = opener.open(request)
        response.read()
        return True
    except urllib2.HTTPError, e:
        print e.read()

    return False



#!/usr/bin/env python
from __future__ import print_function

__VERSION__="2.0.0dev4"

RETURN_CODE_SUCCESS=0
RETURN_CODE_ERROR_NO_CMD=1002

import os
import argparse
from .core import send_data, run_command, handle_normally


API_ENDPOINT = 'http://crondog.hauntdigital.co.nz/api/v1/job'

def main():
    parser = argparse.ArgumentParser(description="A cron job wrapper that sends cron output to cronscape Version %s" % __VERSION__)
    parser.add_argument('-k', '--key', help='Cronscape API key.')
    parser.add_argument('-c', '--cmd', help='Run a command. Could be `cronscape -c "ls -la"`.')

    namespace, sys_args = parser.parse_known_args()

    key=namespace.key if namespace.key else os.environ['CRONDOG_API_KEY'] if 'CRONDOG_API_KEY' in os.environ else None
    cmd=namespace.cmd if namespace.cmd else None

    if not cmd:
        print('\n\n\tA command must be specified\n\n')
        parser.print_help()
        exit(RETURN_CODE_ERROR_NO_CMD)

    command='{cmd} {args}\n'.format(cmd=cmd, args=' '.join(sys_args))

    result = run_command(command)
    if result:
        if key:
            send_data(API_ENDPOINT, result, key)
            exit(RETURN_CODE_SUCCESS)
        else:
            handle_normally(result)
            exit(RETURN_CODE_SUCCESS)

    exit(1)



# -*- coding: utf-8 -*-


"""setup.py: setuptools control."""


import re
from setuptools import setup


version = re.search('^__VERSION__\s*=\s*"(.*)"', open('crondogclient/crondog.py').read(), re.M).group(1)


setup(
    name="Crondog-Client",
    packages=["crondogclient"],
    entry_points={
        "console_scripts": ['crondog=crondogclient.crondog:main']
        },
    install_requires=['argparse'],
    version = version,
    description="Python command line client for crondog.",
    author="Craig Pearson",
    author_email="admin@hauntdigital.co.nz",
    url="http://hauntdigital.co.nz",
    )
